@@ -4,7 +4,9 @@ fn main() {
     let mut hidapi = hidapi::HidApi::new().unwrap();
     let device = StreamDeckDevice::open_first_device(&mut hidapi).unwrap();
 
-    device.on_button_events(|event| {
-        println!("Button {} changed to {:?}", event.button_id, event.state)
-    }).unwrap();
-}
\ No newline at end of file
+    device
+        .on_button_events(|event| {
+            println!("Button {} changed to {:?}", event.button_id, event.state)
+        })
+        .unwrap();
+}
