@@ -3,7 +3,7 @@ pub enum Error {
     NotAStreamDeckDevice,
     NoDeviceFound,
     HidError(hidapi::HidError),
-    DimensionMismatch(u32,u32),
+    DimensionMismatch(u32, u32),
     ImageEncodingError(image::ImageError),
-    IncorrectWriteLengthError
+    IncorrectWriteLengthError,
 }
